/**
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.geronimo.jetty6;

import org.mortbay.jetty.Server;
import org.mortbay.jetty.security.UserRealm;


/**
 * JettyServer extends the base Jetty Server class to prevent managing any user realm information by the web.xml realm name
 * which is only relevant for basic and digest authentication and should not be tied to any
 * actual information about which security realm is in use.
 *
 * @version $Rev: 482336 $ $Date: 2006-12-04 15:12:19 -0500 (Mon, 04 Dec 2006) $
 */
public class JettyServer extends Server {

    public void addUserRealms(UserRealm[] realms) {
        throw new IllegalArgumentException("You must supply a security-realm-name to every web module using security features");
    }

    public void addUserRealm(UserRealm realm) {
        throw new IllegalArgumentException("You must supply a security-realm-name to every web module using security features");
    }

    /**
     * TODO maybe remove intead?
     *
     * @param realm
     * @return
     * @deprecated
     */
    public UserRealm addRealm(UserRealm realm) {
        throw new IllegalArgumentException("You must supply a security-realm-name to every web module using security features");
    }

    /**
     * TODO maybe remove instead?
     *
     * @param realmName
     * @return
     * @deprecated
     */
    public UserRealm getRealm(String realmName) {
        throw new IllegalArgumentException("You must supply a security-realm-name to every web module using security features");
    }

    /**
     * TODO maybe remove instead?
     *
     * @param realm
     * @deprecated
     */
    public synchronized void removeRealm(UserRealm realm) {
        throw new IllegalArgumentException("You must supply a security-realm-name to every web module using security features");
    }

}
